@@ -57,20 +57,21 @@
 				 * curbuf_lock is set */
 #define MODIFY       0x200000L	/* forbidden in non-'modifiable' buffer */
 #define EXFLAGS      0x400000L	/* allow flags after count in argument */
+#define RESTRICT     0x800000L	/* forbidden in restricted mode */
 #define FILES	(XFILE | EXTRA)	/* multiple extra files allowed */
 #define WORD1	(EXTRA | NOSPC)	/* one extra word allowed */
 #define FILE1	(FILES | NOSPC)	/* 1 file allowed, defaults to current file */
 
 /* values for cmd_addr_type */
-#define ADDR_LINES		0
-#define ADDR_WINDOWS		1
-#define ADDR_ARGUMENTS		2
-#define ADDR_LOADED_BUFFERS	3
-#define ADDR_BUFFERS		4
-#define ADDR_TABS		5
-#define ADDR_TABS_RELATIVE	6   /* Tab page that only relative */
-#define ADDR_QUICKFIX		7
-#define ADDR_OTHER		99
+#define ADDR_LINES		0   // buffer line numbers
+#define ADDR_WINDOWS		1   // window number
+#define ADDR_ARGUMENTS		2   // argument number
+#define ADDR_LOADED_BUFFERS	3   // buffer number of loaded buffer
+#define ADDR_BUFFERS		4   // buffer number
+#define ADDR_TABS		5   // tab page number
+#define ADDR_TABS_RELATIVE	6   // Tab page that only relative
+#define ADDR_QUICKFIX		7   // quickfix list entry number
+#define ADDR_OTHER		99  // something else
 
 #ifndef DO_DECLARE_EXCMD
 typedef struct exarg exarg_T;
@@ -456,7 +457,7 @@ EX(CMD_diffthis,	"diffthis",	ex_diffthis,
 			TRLBAR,
 			ADDR_LINES),
 EX(CMD_digraphs,	"digraphs",	ex_digraphs,
-			EXTRA|TRLBAR|CMDWIN,
+			BANG|EXTRA|TRLBAR|CMDWIN,
 			ADDR_LINES),
 EX(CMD_djump,		"djump",	ex_findpat,
 			BANG|RANGE|DFLALL|WHOLEFOLD|EXTRA,
@@ -861,13 +862,13 @@ EX(CMD_lunmap,		"lunmap",	ex_unmap,
 			EXTRA|TRLBAR|NOTRLCOM|USECTRLV|CMDWIN,
 			ADDR_LINES),
 EX(CMD_lua,		"lua",		ex_lua,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_luado,		"luado",	ex_luado,
-			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN,
+			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_luafile,		"luafile",	ex_luafile,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_lvimgrep,	"lvimgrep",	ex_vimgrep,
 			RANGE|NOTADR|BANG|NEEDARG|EXTRA|NOTRLCOM|TRLBAR|XFILE,
@@ -930,10 +931,10 @@ EX(CMD_mode,		"mode",		ex_mode,
 			WORD1|TRLBAR|CMDWIN,
 			ADDR_LINES),
 EX(CMD_mzscheme,	"mzscheme",	ex_mzscheme,
-			RANGE|EXTRA|DFLALL|NEEDARG|CMDWIN|SBOXOK,
+			RANGE|EXTRA|DFLALL|NEEDARG|CMDWIN|SBOXOK|RESTRICT,
 			ADDR_LINES),
 EX(CMD_mzfile,		"mzfile",	ex_mzfile,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_next,		"next",		ex_next,
 			RANGE|NOTADR|BANG|FILES|EDITCMD|ARGOPT|TRLBAR,
@@ -1116,37 +1117,37 @@ EX(CMD_pwd,		"pwd",		ex_pwd,
 			TRLBAR|CMDWIN,
 			ADDR_LINES),
 EX(CMD_python,		"python",	ex_python,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_pydo,		"pydo",		ex_pydo,
-			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN,
+			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_pyfile,		"pyfile",	ex_pyfile,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_py3,		"py3",		ex_py3,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_py3do,		"py3do",	ex_py3do,
-			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN,
+			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_python3,		"python3",	ex_py3,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_py3file,		"py3file",	ex_py3file,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_pyx,		"pyx",		ex_pyx,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_pyxdo,		"pyxdo",	ex_pyxdo,
-			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN,
+			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_pythonx,		"pythonx",	ex_pyx,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_pyxfile,		"pyxfile",	ex_pyxfile,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_quit,		"quit",		ex_quit,
 			BANG|RANGE|COUNT|NOTADR|TRLBAR|CMDWIN,
@@ -1175,6 +1176,9 @@ EX(CMD_redraw,		"redraw",	ex_redraw,
 EX(CMD_redrawstatus,	"redrawstatus",	ex_redrawstatus,
 			BANG|TRLBAR|CMDWIN,
 			ADDR_LINES),
+EX(CMD_redrawtabline,	"redrawtabline", ex_redrawtabline,
+			TRLBAR|CMDWIN,
+			ADDR_LINES),
 EX(CMD_registers,	"registers",	ex_display,
 			EXTRA|NOTRLCOM|TRLBAR|CMDWIN,
 			ADDR_LINES),
@@ -1200,13 +1204,13 @@ EX(CMD_runtime,		"runtime",	ex_runtime,
 			BANG|NEEDARG|FILES|TRLBAR|SBOXOK|CMDWIN,
 			ADDR_LINES),
 EX(CMD_ruby,		"ruby",		ex_ruby,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_rubydo,		"rubydo",	ex_rubydo,
-			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN,
+			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_rubyfile,	"rubyfile",	ex_rubyfile,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_rundo,		"rundo",	ex_rundo,
 			NEEDARG|FILE1,
@@ -1260,11 +1264,14 @@ EX(CMD_sbrewind,	"sbrewind",	ex_brewind,
 			EDITCMD|TRLBAR,
 			ADDR_LINES),
 EX(CMD_scriptnames,	"scriptnames",	ex_scriptnames,
-			TRLBAR|CMDWIN,
-			ADDR_LINES),
+			BANG|RANGE|NOTADR|COUNT|TRLBAR|CMDWIN,
+			ADDR_OTHER),
 EX(CMD_scriptencoding,	"scriptencoding", ex_scriptencoding,
 			WORD1|TRLBAR|CMDWIN,
 			ADDR_LINES),
+EX(CMD_scriptversion,	"scriptversion", ex_scriptversion,
+			WORD1|TRLBAR|CMDWIN,
+			ADDR_LINES),
 EX(CMD_scscope,		"scscope",	ex_scscope,
 			EXTRA|NOTRLCOM,
 			ADDR_LINES),
@@ -1473,13 +1480,13 @@ EX(CMD_tabs,		"tabs",		ex_tabs,
 			TRLBAR|CMDWIN,
 			ADDR_TABS),
 EX(CMD_tcl,		"tcl",		ex_tcl,
-			RANGE|EXTRA|NEEDARG|CMDWIN,
+			RANGE|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_tcldo,		"tcldo",	ex_tcldo,
-			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN,
+			RANGE|DFLALL|EXTRA|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_tclfile,		"tclfile",	ex_tclfile,
-			RANGE|FILE1|NEEDARG|CMDWIN,
+			RANGE|FILE1|NEEDARG|CMDWIN|RESTRICT,
 			ADDR_LINES),
 EX(CMD_tearoff,		"tearoff",	ex_tearoff,
 			NEEDARG|EXTRA|TRLBAR|NOTRLCOM|CMDWIN,
@@ -1667,9 +1674,6 @@ EX(CMD_wq,		"wq",		ex_exit,
 EX(CMD_wqall,		"wqall",	do_wqall,
 			BANG|FILE1|ARGOPT|DFLALL|TRLBAR,
 			ADDR_LINES),
-EX(CMD_wsverb,		"wsverb",	ex_wsverb,
-			EXTRA|NOTADR|NEEDARG,
-			ADDR_LINES),
 EX(CMD_wundo,		"wundo",	ex_wundo,
 			BANG|NEEDARG|FILE1,
 			ADDR_LINES),
@@ -1789,14 +1793,12 @@ struct exarg
     int		force_bin;	/* 0, FORCE_BIN or FORCE_NOBIN */
     int		read_edit;	/* ++edit argument */
     int		force_ff;	/* ++ff= argument (first char of argument) */
-#ifdef FEAT_MBYTE
     int		force_enc;	/* ++enc= argument (index in cmd[]) */
     int		bad_char;	/* BAD_KEEP, BAD_DROP or replacement byte */
-#endif
 #ifdef FEAT_USR_CMDS
     int		useridx;	/* user command index */
 #endif
-    char_u	*errmsg;	/* returned error message */
+    char	*errmsg;	/* returned error message */
     char_u	*(*getline)(int, void *, int);
     void	*cookie;	/* argument for getline() */
 #ifdef FEAT_EVAL
