@@ -18,8 +18,8 @@
 #ifdef AMIGA
 # define DFLT_EFM	"%f>%l:%c:%t:%n:%m,%f:%l: %t%*\\D%n: %m,%f %l %t%*\\D%n: %m,%*[^\"]\"%f\"%*\\D%l: %m,%f:%l:%m,%f|%l| %m"
 #else
-# if defined(WIN3264)
-#  define DFLT_EFM	"%f(%l) : %t%*\\D%n: %m,%*[^\"]\"%f\"%*\\D%l: %m,%f(%l) : %m,%*[^ ] %f %l: %m,%f:%l:%c:%m,%f(%l):%m,%f:%l:%m,%f|%l| %m"
+# if defined(MSWIN)
+#  define DFLT_EFM	"%f(%l) \\=: %t%*\\D%n: %m,%*[^\"]\"%f\"%*\\D%l: %m,%f(%l) \\=: %m,%*[^ ] %f %l: %m,%f:%l:%c:%m,%f(%l):%m,%f:%l:%m,%f|%l| %m"
 # else
 #  if defined(__QNX__)
 #   define DFLT_EFM	"%f(%l):%*[^WE]%t%*\\D%n:%m,%f|%l| %m"
@@ -50,32 +50,23 @@
 # define DFLT_FFS_VI	"dos,unix"	/* also autodetect in compatible mode */
 # define DFLT_TEXTAUTO	TRUE
 #else
-# ifdef USE_CR
-#  define DFLT_FF	"mac"
-#  define DFLT_FFS_VIM	"mac,unix,dos"
-#  define DFLT_FFS_VI	"mac,unix,dos"
-#  define DFLT_TEXTAUTO	TRUE
+# define DFLT_FF	"unix"
+# define DFLT_FFS_VIM	"unix,dos"
+# ifdef __CYGWIN__
+#  define DFLT_FFS_VI	"unix,dos"	/* Cygwin always needs file detection */
+#  define DFLT_TEXTAUTO TRUE
 # else
-#  define DFLT_FF	"unix"
-#  define DFLT_FFS_VIM	"unix,dos"
-#  ifdef __CYGWIN__
-#   define DFLT_FFS_VI	"unix,dos"	/* Cygwin always needs file detection */
-#   define DFLT_TEXTAUTO TRUE
-#  else
-#   define DFLT_FFS_VI	""
-#   define DFLT_TEXTAUTO FALSE
-#  endif
+#  define DFLT_FFS_VI	""
+#  define DFLT_TEXTAUTO FALSE
 # endif
 #endif
 
 
-#ifdef FEAT_MBYTE
 /* Possible values for 'encoding' */
-# define ENC_UCSBOM	"ucs-bom"	/* check for BOM at start of file */
+#define ENC_UCSBOM	"ucs-bom"	/* check for BOM at start of file */
 
 /* default value for 'encoding' */
-# define ENC_DFLT	"latin1"
-#endif
+#define ENC_DFLT	"latin1"
 
 /* end-of-line style */
 #define EOL_UNKNOWN	-1	/* not defined yet */
@@ -101,10 +92,11 @@
 #define FO_WHITE_PAR	'w'	/* trailing white space continues paragr. */
 #define FO_AUTO		'a'	/* automatic formatting */
 #define FO_REMOVE_COMS	'j'	/* remove comment leaders when joining lines */
+#define FO_PERIOD_ABBR	'p'	/* don't break a single space after a period */
 
 #define DFLT_FO_VI	"vt"
 #define DFLT_FO_VIM	"tcq"
-#define FO_ALL		"tcroq2vlb1mMBn,awj"	/* for do_set() */
+#define FO_ALL		"tcroq2vlb1mMBn,awjp"	/* for do_set() */
 
 /* characters for the p_cpo option: */
 #define CPO_ALTREAD	'a'	/* ":read" sets alternate file name */
@@ -201,8 +193,8 @@
 #define SHM_WRI		'w'		/* "[w]" instead of "written" */
 #define SHM_A		"rmfixlnw"	/* represented by 'a' flag */
 #define SHM_WRITE	'W'		/* don't use "written" at all */
-#define SHM_TRUNC	't'		/* trunctate file messages */
-#define SHM_TRUNCALL	'T'		/* trunctate all messages */
+#define SHM_TRUNC	't'		/* truncate file messages */
+#define SHM_TRUNCALL	'T'		/* truncate all messages */
 #define SHM_OVER	'o'		/* overwrite file messages */
 #define SHM_OVERALL	'O'		/* overwrite more messages */
 #define SHM_SEARCH	's'		/* no search hit bottom messages */
@@ -314,10 +306,8 @@ EXTERN long	p_aleph;	/* 'aleph' */
 #ifdef FEAT_AUTOCHDIR
 EXTERN int	p_acd;		/* 'autochdir' */
 #endif
-#ifdef FEAT_MBYTE
 EXTERN char_u	*p_ambw;	/* 'ambiwidth' */
 EXTERN char_u	*p_emoji;	/* 'emoji' */
-#endif
 #if defined(FEAT_GUI) && defined(MACOS_X)
 EXTERN int	*p_antialias;	/* 'antialias' */
 #endif
@@ -394,21 +384,17 @@ EXTERN char_u	*p_bsdir;	/* 'browsedir' */
 #ifdef FEAT_LINEBREAK
 EXTERN char_u	*p_breakat;	/* 'breakat' */
 #endif
-#ifdef FEAT_MBYTE
 EXTERN char_u	*p_cmp;		/* 'casemap' */
 EXTERN unsigned	cmp_flags;
-# ifdef IN_OPTION_C
+#ifdef IN_OPTION_C
 static char *(p_cmp_values[]) = {"internal", "keepascii", NULL};
-# endif
-# define CMP_INTERNAL		0x001
-# define CMP_KEEPASCII		0x002
 #endif
-#ifdef FEAT_MBYTE
+#define CMP_INTERNAL		0x001
+#define CMP_KEEPASCII		0x002
 EXTERN char_u	*p_enc;		/* 'encoding' */
 EXTERN int	p_deco;		/* 'delcombine' */
-# ifdef FEAT_EVAL
+#ifdef FEAT_EVAL
 EXTERN char_u	*p_ccv;		/* 'charconvert' */
-# endif
 #endif
 #ifdef FEAT_CMDWIN
 EXTERN char_u	*p_cedit;	/* 'cedit' */
@@ -481,9 +467,7 @@ EXTERN char_u	*p_gp;		/* 'grepprg' */
 EXTERN char_u	*p_ei;		/* 'eventignore' */
 EXTERN int	p_ek;		/* 'esckeys' */
 EXTERN int	p_exrc;		/* 'exrc' */
-#ifdef FEAT_MBYTE
 EXTERN char_u	*p_fencs;	/* 'fileencodings' */
-#endif
 EXTERN char_u	*p_ffs;		/* 'fileformats' */
 EXTERN long	p_fic;		/* 'fileignorecase' */
 #ifdef FEAT_FOLDING
@@ -518,10 +502,8 @@ EXTERN char_u	*p_pdev;	/* 'printdevice' */
 # ifdef FEAT_POSTSCRIPT
 EXTERN char_u	*p_penc;	/* 'printencoding' */
 EXTERN char_u	*p_pexpr;	/* 'printexpr' */
-#   ifdef FEAT_MBYTE
 EXTERN char_u	*p_pmfn;	/* 'printmbfont' */
 EXTERN char_u	*p_pmcs;	/* 'printmbcharset' */
-#   endif
 # endif
 EXTERN char_u	*p_pfn;		/* 'printfont' */
 EXTERN char_u	*p_popt;	/* 'printoptions' */
@@ -533,9 +515,7 @@ EXTERN char_u	*p_guifont;	/* 'guifont' */
 # ifdef FEAT_XFONTSET
 EXTERN char_u	*p_guifontset;	/* 'guifontset' */
 # endif
-# ifdef FEAT_MBYTE
 EXTERN char_u	*p_guifontwide;	/* 'guifontwide' */
-# endif
 EXTERN int	p_guipty;	/* 'guipty' */
 #endif
 #if defined(FEAT_GUI_GTK) || defined(FEAT_GUI_X11)
@@ -566,10 +546,6 @@ EXTERN long	p_hi;		/* 'history' */
 #ifdef FEAT_RIGHTLEFT
 EXTERN int	p_hkmap;	/* 'hkmap' */
 EXTERN int	p_hkmapp;	/* 'hkmapp' */
-# ifdef FEAT_FKMAP
-EXTERN int	p_fkmap;	/* 'fkmap' */
-EXTERN int	p_altkeymap;	/* 'altkeymap' */
-# endif
 # ifdef FEAT_ARABIC
 EXTERN int	p_arshape;	/* 'arabicshape' */
 # endif
@@ -585,14 +561,12 @@ EXTERN char_u	*p_imak;	/* 'imactivatekey' */
 #define IM_OVER_THE_SPOT	1L
 EXTERN long	p_imst;		/* 'imstyle' */
 #endif
-#if defined(FEAT_EVAL) && defined(FEAT_MBYTE)
+#if defined(FEAT_EVAL)
 EXTERN char_u	*p_imaf;	/* 'imactivatefunc' */
 EXTERN char_u	*p_imsf;	/* 'imstatusfunc' */
 #endif
-#ifdef FEAT_MBYTE
 EXTERN int	p_imcmdline;	/* 'imcmdline' */
 EXTERN int	p_imdisable;	/* 'imdisable' */
-#endif
 EXTERN int	p_is;		/* 'incsearch' */
 EXTERN int	p_im;		/* 'insertmode' */
 EXTERN char_u	*p_isf;		/* 'isfname' */
@@ -628,9 +602,7 @@ EXTERN char_u	*p_luadll;	/* 'luadll' */
 EXTERN int	p_macatsui;	/* 'macatsui' */
 #endif
 EXTERN int	p_magic;	/* 'magic' */
-#ifdef FEAT_MBYTE
 EXTERN char_u	*p_menc;	/* 'makeencoding' */
-#endif
 #ifdef FEAT_QUICKFIX
 EXTERN char_u	*p_mef;		/* 'makeef' */
 EXTERN char_u	*p_mp;		/* 'makeprg' */
@@ -643,9 +615,7 @@ EXTERN char_u   *p_cc;		/* 'colorcolumn' */
 EXTERN int      p_cc_cols[256]; /* array for 'colorcolumn' columns */
 #endif
 EXTERN long	p_mat;		/* 'matchtime' */
-#ifdef FEAT_MBYTE
 EXTERN long	p_mco;		/* 'maxcombine' */
-#endif
 #ifdef FEAT_EVAL
 EXTERN long	p_mfd;		/* 'maxfuncdepth' */
 #endif
@@ -720,7 +690,7 @@ EXTERN long	p_report;	/* 'report' */
 #if defined(FEAT_QUICKFIX)
 EXTERN long	p_pvh;		/* 'previewheight' */
 #endif
-#ifdef WIN3264
+#ifdef MSWIN
 EXTERN int	p_rs;		/* 'restorescreen' */
 #endif
 #ifdef FEAT_RIGHTLEFT
@@ -849,12 +819,13 @@ EXTERN char_u	*p_tcldll;	/* 'tcldll' */
 #ifdef FEAT_ARABIC
 EXTERN int	p_tbidi;	/* 'termbidi' */
 #endif
-#ifdef FEAT_MBYTE
 EXTERN char_u	*p_tenc;	/* 'termencoding' */
-#endif
 #ifdef FEAT_TERMGUICOLORS
 EXTERN int	p_tgc;		/* 'termguicolors' */
 #endif
+#if defined(MSWIN) && defined(FEAT_TERMINAL)
+EXTERN char_u	*p_twt;		// 'termwintype'
+#endif
 EXTERN int	p_terse;	/* 'terse' */
 EXTERN int	p_ta;		/* 'textauto' */
 EXTERN int	p_to;		/* 'tildeop' */
@@ -873,7 +844,7 @@ EXTERN int	p_ttimeout;	/* 'ttimeout' */
 EXTERN long	p_ttm;		/* 'ttimeoutlen' */
 EXTERN int	p_tbi;		/* 'ttybuiltin' */
 EXTERN int	p_tf;		/* 'ttyfast' */
-#if defined(FEAT_TOOLBAR) && !defined(FEAT_GUI_W32)
+#if defined(FEAT_TOOLBAR) && !defined(FEAT_GUI_MSWIN)
 EXTERN char_u	*p_toolbar;	/* 'toolbar' */
 EXTERN unsigned toolbar_flags;
 # ifdef IN_OPTION_C
@@ -929,17 +900,15 @@ EXTERN char_u	*p_vop;		/* 'viewoptions' */
 EXTERN unsigned	vop_flags;	/* uses SSOP_ flags */
 #endif
 EXTERN int	p_vb;		/* 'visualbell' */
-#ifdef FEAT_VIRTUALEDIT
 EXTERN char_u	*p_ve;		/* 'virtualedit' */
 EXTERN unsigned ve_flags;
-# ifdef IN_OPTION_C
+#ifdef IN_OPTION_C
 static char *(p_ve_values[]) = {"block", "insert", "all", "onemore", NULL};
-# endif
-# define VE_BLOCK	5	/* includes "all" */
-# define VE_INSERT	6	/* includes "all" */
-# define VE_ALL		4
-# define VE_ONEMORE	8
 #endif
+#define VE_BLOCK	5	/* includes "all" */
+#define VE_INSERT	6	/* includes "all" */
+#define VE_ALL		4
+#define VE_ONEMORE	8
 EXTERN long	p_verbose;	/* 'verbose' */
 #ifdef IN_OPTION_C
 char_u	*p_vfile = (char_u *)""; /* used before options are initialized */
@@ -972,7 +941,7 @@ EXTERN long	p_wh;		/* 'winheight' */
 EXTERN long	p_wmh;		/* 'winminheight' */
 EXTERN long	p_wmw;		/* 'winminwidth' */
 EXTERN long	p_wiw;		/* 'winwidth' */
-#if defined(WIN3264) && defined(FEAT_TERMINAL)
+#if defined(MSWIN) && defined(FEAT_TERMINAL)
 EXTERN char_u	*p_winptydll;	/* 'winptydll' */
 #endif
 EXTERN int	p_ws;		/* 'wrapscan' */
@@ -1000,9 +969,7 @@ enum
 #endif
     , BV_BIN
     , BV_BL
-#ifdef FEAT_MBYTE
     , BV_BOMB
-#endif
     , BV_CI
 #ifdef FEAT_CINDENT
     , BV_CIN
@@ -1067,9 +1034,7 @@ enum
     , BV_LISP
     , BV_LW
 #endif
-#ifdef FEAT_MBYTE
     , BV_MENC
-#endif
     , BV_MA
     , BV_ML
     , BV_MOD
@@ -1179,6 +1144,8 @@ enum
 #endif
     , WV_SCBIND
     , WV_SCROLL
+    , WV_SISO
+    , WV_SO
 #ifdef FEAT_SPELL
     , WV_SPELL
 #endif
